intelmq.bots.experts.url2fqdn package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.url2fqdn package

## Submodules

## intelmq.bots.experts.url2fqdn.expert module

intelmq.bots.experts.url2fqdn.expert.BOT

  alias of `intelmq.bots.experts.url2fqdn.expert.Url2fqdnExpertBot`

class intelmq.bots.experts.url2fqdn.expert.Url2fqdnExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ExpertBot`

  Parse the FQDN from the URL

  overwrite = False
  process()

## Module contents